import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:syncrow_web/pages/analytics/models/range_of_aqi.dart';
import 'package:syncrow_web/pages/analytics/params/get_range_of_aqi_param.dart';
import 'package:syncrow_web/pages/analytics/services/range_of_aqi/range_of_aqi_service.dart';

part 'range_of_aqi_event.dart';
part 'range_of_aqi_state.dart';

class RangeOfAqiBloc extends Bloc<RangeOfAqiEvent, RangeOfAqiState> {
  RangeOfAqiBloc(this._rangeOfAqiService) : super(const RangeOfAqiState()) {
    on<LoadRangeOfAqiEvent>(_onLoadRangeOfAqiEvent);
    on<ClearRangeOfAqiEvent>(_onClearRangeOfAqiEvent);
  }

  final RangeOfAqiService _rangeOfAqiService;

  Future<void> _onLoadRangeOfAqiEvent(
    LoadRangeOfAqiEvent event,
    Emitter<RangeOfAqiState> emit,
  ) async {
    emit(
      RangeOfAqiState(
        status: RangeOfAqiStatus.loading,
        rangeOfAqi: state.rangeOfAqi,
      ),
    );
    try {
      final rangeOfAqi = await _rangeOfAqiService.load(event.param);
      emit(RangeOfAqiState(status: RangeOfAqiStatus.loaded, rangeOfAqi: rangeOfAqi));
    } catch (e) {
      emit(RangeOfAqiState(status: RangeOfAqiStatus.failure, errorMessage: '$e'));
    }
  }

  void _onClearRangeOfAqiEvent(
    ClearRangeOfAqiEvent event,
    Emitter<RangeOfAqiState> emit,
  ) {
    emit(const RangeOfAqiState());
  }
}
