import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/air_quality/blocs/range_of_aqi/range_of_aqi_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/air_quality/widgets/aqi_type_dropdown.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_date_picker_bloc/analytics_date_picker_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_devices/analytics_devices_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/realtime_device_changes/realtime_device_changes_bloc.dart';
import 'package:syncrow_web/pages/analytics/params/get_analytics_devices_param.dart';
import 'package:syncrow_web/pages/analytics/params/get_range_of_aqi_param.dart';

abstract final class FetchAirQualityDataHelper {
  const FetchAirQualityDataHelper._();

  static void loadAirQualityData(
    BuildContext context, {
    required String communityUuid,
    required String spaceUuid,
  }) {
    final date = context.read<AnalyticsDatePickerBloc>().state.monthlyDate;
    loadAnalyticsDevices(
      context,
      communityUuid: communityUuid,
      spaceUuid: spaceUuid,
    );
    loadRangeOfAqi(
      context,
      spaceUuid: spaceUuid,
      date: date,
      aqiType: AqiType.aqi,
    );
  }

  static void clearAllData(BuildContext context) {
    context.read<AnalyticsDevicesBloc>().add(
          const ClearAnalyticsDeviceEvent(),
        );
    context.read<RealtimeDeviceChangesBloc>().add(
          const RealtimeDeviceChangesClosed(),
        );

    context.read<RangeOfAqiBloc>().add(const ClearRangeOfAqiEvent());
  }

  static void loadAnalyticsDevices(
    BuildContext context, {
    required String communityUuid,
    required String spaceUuid,
  }) {
    context.read<AnalyticsDevicesBloc>().add(
          LoadAnalyticsDevicesEvent(
            param: GetAnalyticsDevicesParam(
              communityUuid: communityUuid,
              spaceUuid: spaceUuid,
              deviceTypes: ['AQI'],
              requestType: AnalyticsDeviceRequestType.energyManagement,
            ),
            onSuccess: (device) {
              context.read<RealtimeDeviceChangesBloc>()
                ..add(const RealtimeDeviceChangesClosed())
                ..add(RealtimeDeviceChangesStarted(device.uuid));
            },
          ),
        );
  }

  static void loadRangeOfAqi(
    BuildContext context, {
    required String spaceUuid,
    required DateTime date,
    required AqiType aqiType,
  }) {
    context.read<RangeOfAqiBloc>().add(
          LoadRangeOfAqiEvent(
            GetRangeOfAqiParam(
              date: date,
              spaceUuid: spaceUuid,
              aqiType: aqiType,
            ),
          ),
        );
  }
}
