import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_devices/analytics_devices_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/helpers/fetch_energy_management_data_helper.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/widgets/analytics_device_dropdown.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';
import 'package:syncrow_web/utils/style.dart';

class AirQualityEndSideWidget extends StatelessWidget {
  const AirQualityEndSideWidget({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: subSectionContainerDecoration.copyWith(
        borderRadius: BorderRadius.circular(30),
      ),
      padding: const EdgeInsetsDirectional.all(32),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildHeader(context),
          Text(
            'Device ID:',
            style: context.textTheme.bodySmall?.copyWith(
              color: ColorsManager.textPrimaryColor,
              fontWeight: FontWeight.w400,
              fontSize: 12,
            ),
          ),
          const SizedBox(height: 6),
          SelectableText(
            context.watch<AnalyticsDevicesBloc>().state.selectedDevice?.uuid ??
                'N/A',
            style: context.textTheme.bodySmall?.copyWith(
              color: ColorsManager.blackColor,
              fontWeight: FontWeight.w400,
              fontSize: 12,
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildHeader(BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        Expanded(
          flex: 3,
          child: FittedBox(
            alignment: AlignmentDirectional.centerStart,
            child: SelectableText(
              'AQI Sensor',
              style: context.textTheme.headlineSmall?.copyWith(
                fontWeight: FontWeight.w700,
                color: ColorsManager.vividBlue.withValues(alpha: 0.6),
                fontSize: 18,
              ),
            ),
          ),
        ),
        const Spacer(),
        Expanded(
          flex: 4,
          child: FittedBox(
            alignment: AlignmentDirectional.centerEnd,
            child: AnalyticsDeviceDropdown(
              onChanged: (value) {
                context.read<AnalyticsDevicesBloc>().add(
                      SelectAnalyticsDeviceEvent(value),
                    );
                FetchEnergyManagementDataHelper.loadRealtimeDeviceChanges(
                  context,
                  deviceUuid: value.uuid,
                );
              },
            ),
          ),
        ),
      ],
    );
  }
}
