import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

enum AqiType {
  aqi('AQI'),
  pm25('PM2.5'),
  pm10('PM10'),
  hcho('HCHO'),
  tvoc('TVOC'),
  co2('CO2'),
  c6h6('C6H6');

  final String value;
  const AqiType(this.value);
}

class AqiTypeDropdown extends StatefulWidget {
  const AqiTypeDropdown({super.key, required this.onChanged});

  final ValueChanged<AqiType?> onChanged;

  @override
  State<AqiTypeDropdown> createState() => _AqiTypeDropdownState();
}

class _AqiTypeDropdownState extends State<AqiTypeDropdown> {
  AqiType? _selectedItem = AqiType.aqi;

  void _updateSelectedItem(AqiType? item) => setState(() => _selectedItem = item);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(16),
        border: Border.all(
          color: ColorsManager.greyColor,
          width: 1,
        ),
      ),
      child: DropdownButton<AqiType?>(
        value: _selectedItem,
        isDense: true,
        borderRadius: BorderRadius.circular(16),
        dropdownColor: ColorsManager.whiteColors,
        underline: const SizedBox.shrink(),
        icon: const RotatedBox(
          quarterTurns: 1,
          child: Icon(Icons.chevron_right, size: 24),
        ),
        style: _getTextStyle(context),
        padding: const EdgeInsetsDirectional.symmetric(
          horizontal: 12,
          vertical: 2,
        ),
        items: AqiType.values
            .map((e) => DropdownMenuItem(value: e, child: Text(e.value)))
            .toList(),
        onChanged: (value) {
          _updateSelectedItem(value);
          widget.onChanged(value);
        },
      ),
    );
  }

  TextStyle? _getTextStyle(BuildContext context) {
    return context.textTheme.labelSmall?.copyWith(
      color: ColorsManager.textPrimaryColor,
      fontWeight: FontWeight.w700,
      fontSize: 12,
    );
  }
}
